@@ -1,6 +1,7 @@
 from datetime import datetime
 
 import sqlalchemy
+from fastapi_users_db_sqlalchemy import SQLAlchemyBaseUserTableUUID
 from sqlalchemy import Column, DateTime, Float, ForeignKey, Integer, String, orm
 
 from defi_common.database import db
@@ -84,3 +85,7 @@ class CoinChangeRank(db.Base):  # type. ignore
     time = Column(DateTime(), nullable=False)
     pct_change = Column(Float, nullable=False)
     ranking_type = Column(String, nullable=False)
+
+
+class User(SQLAlchemyBaseUserTableUUID, db.Base):
+    pass
